########## Binaly Logit Model ##########

#<<<First step>>>
##### Data Reading from csv file #####
Data <- read.csv("use_data2.csv")
names(Data)
summary(Data)

#<<<Second step>>>
##### Defining Log-likehood function #####
LL <- function (time,cost,female,DBusiness,Dcar,b1)
{
  Rational <- exp(Data$ChoiceTime*time/100 + Data$ChoiceCost*cost/100 + Data$DummySex_female*female  + Data$PurposeBusiness*DBusiness + Data$DummyCar*Dcar+b1)
  Irrational <- exp(0)

  # Denominator
  Sum <- (Rational + Irrational)
  
  # Probabilities
  P1 <- Rational/Sum
  P2 <- Irrational/Sum
 
  
  ## Avoid problems stemming from choice probabilities becoming zero.
  P1  <- (P1!=0)*P1+(P1==0)
  P2  <- (P2!=0)*P2+(P2==0)
  
  
  # Dummies (or indicator) for choice
  D1 <- ifelse(Data$RationalIrrational == "Rational",1,0)
  D2 <- ifelse(Data$RationalIrrational == "Irrational",1,0)
  
  
  # Log-likelihood function
  L <- -sum(D1*log(P1) + D2*log(P2))
  return(L)
} #End function


#<<<Third step>>>
##### Model Estimation #####
initValue <- list(time=0,cost=0,female=0,DBusiness=0,Dcar=0,b1=0)
#install packages: NoOTICE: Packages is needed to install for the first time using the packages
# install.packages("bbmle")
library(bbmle)
MNL <- mle2(LL, start = initValue, method = "BFGS", control = list(trace = 10000, maxit = 10000))
summary(MNL)

#<<<Fourth step>>>
LL0 <- NROW(Data)*log(1/2)     ## Initial log-likelihood
LL1 <- logLik(MNL)             ## Converged log-likelihood
## McFadden's Rho square
Rho     <- 1-(LL1/LL0)
Rho.adj <- 1-((LL1-length(coef(MNL)))/LL0)
GoF <- cbind(LL0,LL1, Rho, Rho.adj)  ## Goodness of fit
print(GoF)

