########## Multinomial Logit Model ##########

#<<<First step>>>
##### Data Reading from csv file #####
Data <- read.csv("use_data.csv")
names(Data)
summary(Data)

#<<<Second step>>>
##### Defining Log-likehood function #####
LL <- function (Rational_time,Irrational_time,Rational_cost,Irrational_cost,female,age_over50,b1,b2,b3,b4)
{

  Train <- exp((Data$DummyRational*Rational_time+Data$DummyIrrational*Irrational_time)*Data$TotalTimeTrain/100 +(Data$DummyRational*Rational_cost+Data$DummyIrrational*Irrational_cost)*Data$FareTrain/100 + b1)
  Bus   <- exp((Data$DummyRational*Rational_time+Data$DummyIrrational*Irrational_time)*Data$TotalTimeBus/100 +(Data$DummyRational*Rational_cost+Data$DummyIrrational*Irrational_cost)*Data$FareBus/100 +Data$DummySex_female*female +Data$DummyAge_over50*age_over50 + b2)
  Car   <- exp((Data$DummyRational*Rational_time+Data$DummyIrrational*Irrational_time)*Data$TimeCar/100 +(Data$DummyRational*Rational_cost+Data$DummyIrrational*Irrational_cost)*Data$CostCar/100 + b3)
  Bike  <- exp((Data$DummyRational*Rational_time+Data$DummyIrrational*Irrational_time)*Data$TimeBike/100 +Data$DummySex_female*female+ b4)
  Walk  <- exp((Data$DummyRational*Rational_time+Data$DummyIrrational*Irrational_time)*Data$TimeWalk/100)

  # Denominator
  Sum <- (Train + Bus + Car + Bike + Walk)
  
  # Probabilities
  P1 <- Train/Sum
  P2 <- Bus/Sum
  P3 <- Car/Sum
  P4 <- Bike/Sum
  P5 <- Walk/Sum
  
  ## Avoid problems stemming from choice probabilities becoming zero.
  P1  <- (P1!=0)*P1+(P1==0)
  P2  <- (P2!=0)*P2+(P2==0)
  P3  <- (P3!=0)*P3+(P3==0)
  P4  <- (P4!=0)*P4+(P4==0)
  P5  <- (P5!=0)*P5+(P5==0)
  
  
  # Dummies (or indicator) for choice
  D1 <- ifelse(Data$MainMode == "Rail",1,0)
  D2 <- ifelse(Data$MainMode == "Bus",1,0)
  D3 <- ifelse(Data$MainMode == "Car",1,0)
  D4 <- ifelse(Data$MainMode == "Bicycle",1,0)
  D5 <- ifelse(Data$MainMode == "Walk",1,0)
  
  # Log-likelihood function
  L <- -sum(D1*log(P1) + D2*log(P2) + D3*log(P3) + D4*log(P4) + D5*log(P5))
  return(L)
} #End function


#<<<Third step>>>
##### Model Estimation #####
initValue <- list(Rational_time=0,Irrational_time=0,Rational_cost=0,Irrational_cost=0,female=0,age_over50=0,b1=0,b2=0,b3=0,b4=0)
#install packages: NoOTICE: Packages is needed to install for the first time using the packages
# install.packages("bbmle")
library(bbmle)
MNL <- mle2(LL, start = initValue, method = "BFGS", control = list(trace = 10000, maxit = 10000))
summary(MNL)

#<<<Fourth step>>>
LL0 <- NROW(Data)*log(1/5)     ## Initial log-likelihood
LL1 <- logLik(MNL)             ## Converged log-likelihood
## McFadden's Rho square
Rho     <- 1-(LL1/LL0)
Rho.adj <- 1-((LL1-length(coef(MNL)))/LL0)
GoF <- cbind(LL0,LL1, Rho, Rho.adj)  ## Goodness of fit
print(GoF)

